@@ -1,26 +1,27 @@
-;;; gitconfig-mode.el --- Major mode for editing .gitconfig files  -*- lexical-binding: t -*-
+;;; gitconfig-mode.el --- Major mode for editing .gitconfig files  -*- lexical-binding:t -*-
 
-;; Copyright (c) 2012-2013  Sebastian Wiesner
-;; Copyright (C) 2012-2021  The Magit Project Contributors
+;; Copyright (c) 2012-2013 Sebastian Wiesner
+;; Copyright (C) 2012-2023 The Magit Project Contributors
 
 ;; Author: Sebastian Wiesner <lunaryorn@gmail.com>
 ;; Maintainer: Jonas Bernoulli <jonas@bernoul.li>
 ;; Homepage: https://github.com/magit/git-modes
 ;; Keywords: convenience vc git
+
 ;; SPDX-License-Identifier: GPL-3.0-or-later
 
-;; This file is free software; you can redistribute it and/or modify
+;; This file is free software: you can redistribute it and/or modify
 ;; it under the terms of the GNU General Public License as published
-;; by the Free Software Foundation; either version 3 of the License,
+;; by the Free Software Foundation, either version 3 of the License,
 ;; or (at your option) any later version.
-
+;;
 ;; This file is distributed in the hope that it will be useful,
 ;; but WITHOUT ANY WARRANTY; without even the implied warranty of
 ;; MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 ;; GNU General Public License for more details.
-
+;;
 ;; You should have received a copy of the GNU General Public License
-;; along with this file.  If not, see <http://www.gnu.org/licenses/>.
+;; along with this file.  If not, see <https://www.gnu.org/licenses/>.
 
 ;;; Commentary:
 
@@ -28,8 +29,9 @@
 
 ;;; Code:
 
-(require 'rx)
+(require 'compat)
 (require 'conf-mode)
+(require 'rx)
 
 (defun gitconfig-line-indented-p ()
   "Return t if the current line is indented correctly."
